@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "captchadialog.h"
 #include "../shared/utils.h"
 #include <QLabel>
@@ -72,7 +89,7 @@ void CaptchaDialog::setTimeout(int secs) {
 
         if (!m_timer) {
             m_timer = new QTimer(this);
-            connect(m_timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
+            this->connect(m_timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
         }
 
         m_timeoutLabel->setText(Utils::durationFromSecs(m_timeout));
