@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "../shared/session.h"
 #include "../shared/transfermodel.h"
 #include "../shared/pluginmanager.h"
@@ -14,10 +31,10 @@
 #include "../shared/packagetransfermodel.h"
 #include "../shared/archivepasswordsmodel.h"
 #include "../shared/definitions.h"
+#include "../shared/utils.h"
 #include "../dbus/dbusservice.h"
 #include "../dbus/dbusserviceadaptor.h"
 #include "folderlistmodel.h"
-#include "qmlutils.h"
 #include "maskeditem.h"
 #include <QApplication>
 #include <MDeclarativeCache>
@@ -30,7 +47,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QScopedPointer<QDeclarativeView> view(MDeclarativeCache::qDeclarativeView());
 
     Session session;
-    QmlUtils utils;
+    Utils utils;
     DBusServiceAdaptor adaptor(DBusService::instance());
 
     QDBusConnection connection = QDBusConnection::sessionBus();
