@@ -1,6 +1,24 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include "../shared/enums.h"
 #include <QMainWindow>
 
 class QLineEdit;
@@ -32,10 +50,14 @@ private slots:
     void onPluginsReady();
     void onPackageCountChanged(int count);
     void setNextAction();
+    void onNextActionChanged(Transfers::Action action);
     void setTransferStatusFilter();
     void setMaximumConcurrentTransfers();
+    void onMaximumConcurrentTransfersChanged(int oldMax, int newMax);
     void setGlobalTransferConnections();
+    void onGlobalTransferConnectionsChanged(int oldMax, int newMax);
     void setDownloadRateLimit();
+    void onDownloadRateLimitChanged(int limit);
     void updateSpeed(int speed);
     void setTransferMenuActions();
     void setPackageMenuActions();
@@ -56,7 +78,9 @@ private slots:
     void setCurrentPackageCategory();
     void setCurrentPackagePriority();
     void showAddUrlsDialog(const QString &text = QString(), const QString &fileName = QString());
+    void addUrlsFromText(const QString &text);
     void showRetrieveUrlsDialog(const QString &text = QString(), const QString &fileName = QString());
+    void retrieveUrlsFromText(const QString &text);
     void onUrlRetrieverFinished();
     void showTextFileDialog();
     void showAboutDialog();
