@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -30,10 +47,14 @@ protected:
 private slots:
     void onPluginsReady();
     void setNextAction(const QVariant &value);
+    void onNextActionChanged(Transfers::Action action);
     void setTransferFilter(const QVariant &value);
     void setMaximumConcurrentTransfers(const QVariant &value);
+    void onMaximumConcurrentTransfersChanged(int oldMax, int newMax);
     void setGlobalTransferConnections(const QVariant &value);
+    void onGlobalTransferConnectionsChanged(int oldMax, int newMax);
     void setDownloadRateLimit(const QVariant &value);
+    void onDownloadRateLimitChanged(int limit);
     void updateSpeed(int speed);
     void onPackageCountChanged(int count);
     void setTransferMenuActions();
@@ -51,7 +72,9 @@ private slots:
     void setCurrentTransferCategory(const QVariant &category);
     void setCurrentTransferPriority(const QVariant &priority);
     void showAddUrlsDialog(const QString &text = QString(), const QString &fileName = QString());
+    void addUrlsFromText(const QString &text);
     void showRetrieveUrlsDialog(const QString &text = QString(), const QString &fileName = QString());
+    void retrieveUrlsFromText(const QString &text);
     void onUrlRetrieverFinished();
     void showTextFileDialog();
     void showAboutDialog();
