@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "pluginmanager.h"
 #include "../interfaces/serviceplugin.h"
 #include "../interfaces/decaptchaplugin.h"
@@ -17,21 +34,21 @@
 #define LIB_EXT "*.dll"
 #endif
 
-PluginManager* PluginManager::m_instance = 0;
+PluginManager* PluginManager::self = 0;
 
 PluginManager::PluginManager() :
     QObject(),
     m_progress(0)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 PluginManager::~PluginManager() {}
 
 PluginManager* PluginManager::instance() {
-    return !m_instance ? new PluginManager : m_instance;
+    return !self ? new PluginManager : self;
 }
 
 void PluginManager::loadPlugins() {
