@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "settings.h"
 #include "definitions.h"
 #include <qplatformdefs.h>
@@ -10,7 +27,7 @@
 #include <QDesktopServices>
 #endif
 
-Settings* Settings::m_instance = 0;
+Settings* Settings::self = 0;
 
 Settings::Settings() :
     QSettings(QString("QDL"), QString("QDL")),
@@ -26,9 +43,14 @@ Settings::Settings() :
     m_deleteArchives(true),
     m_proxyType(NetworkProxyType::HttpProxy),
     m_proxyPort(80)
+  #ifdef WEB_INTERFACE
+    ,m_enableWebIf(false),
+    m_webIfPort(8080),
+    m_webIfTheme("Default")
+  #endif
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->restoreSettings();
@@ -39,7 +61,7 @@ Settings::~Settings() {
 }
 
 Settings* Settings::instance() {
-    return !m_instance ? new Settings : m_instance;
+    return !self ? new Settings : self;
 }
 
 void Settings::restoreSettings() {
@@ -78,6 +100,14 @@ void Settings::restoreSettings() {
     this->setNetworkProxy();
     this->endGroup();
 
+#ifdef WEB_INTERFACE
+    this->beginGroup("Interfaces");
+    this->setEnableWebInterface(this->value("enableWebInterface", false).toBool());
+    this->setWebInterfacePort(this->value("webInterfacePort", 8080).toLongLong());
+    this->setWebInterfaceTheme(this->value("webInterfaceTheme", QString("Default")).toString());
+    this->endGroup();
+#endif
+
     this->beginGroup("Other");
     this->setLanguage(this->value("language", QString("en")).toString());
     this->setMonitorClipboard(this->value("monitorClipboard", false).toBool());
@@ -110,6 +140,14 @@ void Settings::saveSettings() {
     this->setValue("networkProxyPassword", this->networkProxyPassword().toUtf8().toBase64());
     this->endGroup();
 
+#ifdef WEB_INTERFACE
+    this->beginGroup("Interfaces");
+    this->setValue("enableWebInterface", this->enableWebInterface());
+    this->setValue("webInterfacePort", this->webInterfacePort());
+    this->setValue("webInterfaceTheme", this->webInterfaceTheme());
+    this->endGroup();
+#endif
+
     this->beginGroup("Other");
     this->setValue("language", this->language());
     this->setValue("monitorClipboard", this->monitorClipboard());
@@ -284,3 +322,26 @@ void Settings::onNetworkProxyAuthenticationRequested(const QNetworkProxy &proxy,
     authenticator->setUser(this->networkProxyUser());
     authenticator->setPassword(this->networkProxyPassword());
 }
+
+#ifdef WEB_INTERFACE
+void Settings::setEnableWebInterface(bool enable) {
+    if (enable != this->enableWebInterface()) {
+        m_enableWebIf = enable;
+        emit enableWebInterfaceChanged(enable);
+    }
+}
+
+void Settings::setWebInterfacePort(quint16 port) {
+    if (port != this->webInterfacePort()) {
+        m_webIfPort = port;
+        emit webInterfacePortChanged(port);
+    }
+}
+
+void Settings::setWebInterfaceTheme(const QString &theme) {
+    if (theme != this->webInterfaceTheme()) {
+        m_webIfTheme = theme;
+        emit webInterfaceThemeChanged(theme);
+    }
+}
+#endif
