@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "storage.h"
 #include "connection.h"
 #include <QXmlStreamReader>
@@ -10,13 +27,13 @@
 #include <QDesktopServices>
 #endif
 
-Storage* Storage::m_instance = 0;
+Storage* Storage::self = 0;
 
 Storage::Storage() :
     QObject()
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 #if QT_VERSION >= 0x050000
     this->setDirectory(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/.QDL/");
@@ -28,7 +45,7 @@ Storage::Storage() :
 Storage::~Storage() {}
 
 Storage* Storage::instance() {
-    return !m_instance ? new Storage : m_instance;
+    return !self ? new Storage : self;
 }
 
 QString Storage::directory() const {
@@ -166,7 +183,11 @@ bool Storage::restoreTransfers() {
 
     while ((!reader.atEnd()) && (!reader.hasError())) {
         while ((!reader.atEnd()) && (!reader.hasError()) && (reader.name() != "package")) {
-            reader.readNextStartElement();
+            while (reader.readNext() != QXmlStreamReader::Invalid) {
+                if ((reader.isStartElement()) || (reader.isEndElement())) {
+                    break;
+                }
+            }
         }
 
         if (reader.name() == "package") {
@@ -176,13 +197,21 @@ bool Storage::restoreTransfers() {
 
             QList<Transfer*> packageTransfers;
 
-            reader.readNextStartElement();
+            while (reader.readNext() != QXmlStreamReader::Invalid) {
+                if ((reader.isStartElement()) || (reader.isEndElement())) {
+                    break;
+                }
+            }
 
             if (reader.name() == "transfer") {
                 while ((!reader.atEnd()) && (!reader.hasError()) && (reader.name() != "package")) {
                     Transfer *transfer = new Transfer;
 
-                    reader.readNextStartElement();
+                    while (reader.readNext() != QXmlStreamReader::Invalid) {
+                        if ((reader.isStartElement()) || (reader.isEndElement())) {
+                            break;
+                        }
+                    }
 
                     while ((!reader.atEnd()) && (!reader.hasError()) && (reader.name() != "transfer")) {
                         if (reader.name() == "id") {
@@ -222,13 +251,25 @@ bool Storage::restoreTransfers() {
                             transfer->restoreConnection(reader.attributes().value("position").toString().toLongLong(),
                                                         reader.attributes().value("end").toString().toLongLong());
 
-                            reader.readNextStartElement();
+                            while (reader.readNext() != QXmlStreamReader::Invalid) {
+                                if ((reader.isStartElement()) || (reader.isEndElement())) {
+                                    break;
+                                }
+                            }
                         }
 
-                        reader.readNextStartElement();
+                        while (reader.readNext() != QXmlStreamReader::Invalid) {
+                            if ((reader.isStartElement()) || (reader.isEndElement())) {
+                                break;
+                            }
+                        }
                     }
 
-                    reader.readNextStartElement();
+                    while (reader.readNext() != QXmlStreamReader::Invalid) {
+                        if ((reader.isStartElement()) || (reader.isEndElement())) {
+                            break;
+                        }
+                    }
 
                     packageTransfers.append(transfer);
                 }
