@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "transfer.h"
 #include "utils.h"
 #include "database.h"
@@ -566,7 +583,9 @@ void Transfer::setStatus(Transfers::Status status) {
             m_downloadTime.start();
             break;
         case Transfers::Cancelled:
-            m_file.remove();
+            if (!m_file.remove()) {
+                QFile::remove(QString("%1%2%3").arg(this->downloadPath()).arg(this->downloadPath().endsWith("/") ? "" : "/").arg(this->fileName()));
+            }
 
             if ((m_transfers.isEmpty()) && (this->isPackage())) {
                 QDir().rmdir(this->downloadPath());
@@ -910,6 +929,7 @@ void Transfer::start() {
     case Transfers::Paused:
     case Transfers::Failed:
     case Transfers::Queued:
+    case Transfers::ShortWait:
 	break;
     default:
 	return;
@@ -1417,10 +1437,12 @@ void Transfer::moveFiles() {
 
     foreach (QString oldFileName, downloadDir.entryList(QDir::Files)) {
         QString fileName = destinationDir.path() + "/" + oldFileName;
+
         int i = 1;
 
         while ((destinationDir.exists(fileName)) && (i < 100)) {
-            fileName = QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('.'))).arg(i).arg(fileName.mid(fileName.lastIndexOf('.')));
+            fileName = (i == 1 ? QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('.'))).arg(i).arg(fileName.mid(fileName.lastIndexOf('.')))
+                              : QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('('))).arg(i).arg(fileName.mid(fileName.lastIndexOf('.'))));
             i++;
         }
 
