@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "transfermodel.h"
 #include "transfer.h"
 #include "storage.h"
@@ -7,7 +24,7 @@
 #include <QTimer>
 #include <QCoreApplication>
 
-TransferModel* TransferModel::m_instance = 0;
+TransferModel* TransferModel::self = 0;
 
 TransferModel::TransferModel() :
     QAbstractItemModel(),
@@ -16,8 +33,8 @@ TransferModel::TransferModel() :
     m_statusFilter(Transfers::Unknown),
     m_nextAction(Transfers::Continue)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     m_roleNames[Transfer::NameRole] = "name";
@@ -60,7 +77,7 @@ TransferModel::TransferModel() :
 TransferModel::~TransferModel() {}
 
 TransferModel* TransferModel::instance() {
-    return !m_instance ? new TransferModel : m_instance;
+    return !self ? new TransferModel : self;
 }
 
 #if (QT_VERSION >= 0x050000) || (QT_VERSION < 0x040600)
@@ -208,13 +225,94 @@ QVariantMap TransferModel::itemData(const QString &id) const {
     return QVariantMap();
 }
 
-QVariantList TransferModel::allItemData() const {
+QVariantList TransferModel::allItemData(Transfers::Status filter, const QString &query, int start, int count) const {
     QVariantList list;
 
-    foreach (Transfer *transfer, m_rootItem->childTransfers()) {
-        list.append(transfer->itemDataWithRoleNames());
+    if ((start < 0) || (start > m_rootItem->count())) {
+        start = 0;
+    }
 
-        foreach (Transfer *childTransfer, transfer->childTransfers()) {
+    count = start + count;
+
+    if ((count <= 0) || (count > m_rootItem->count())) {
+        count = m_rootItem->count();
+    }
+
+    int matches = 0;
+
+    switch (filter) {
+    case Transfers::Unknown:
+        if (!query.isEmpty()) {
+            foreach (Transfer *transfer, m_rootItem->childTransfers()) {
+                if (transfer->match(Transfer::NameRole, query)) {
+                    matches++;
+
+                    if (matches > start) {
+                        list.append(transfer->itemDataWithRoleNames());
+
+                        foreach (Transfer *childTransfer, transfer->childTransfers()) {
+                            list.append(childTransfer->itemDataWithRoleNames());
+                        }
+                    }
+
+                    if (matches >= (start + count)) {
+                        break;
+                    }
+                }
+            }
+
+            return list;
+        }
+
+        break;
+    default:
+        if (!query.isEmpty()) {
+            foreach (Transfer *transfer, m_rootItem->childTransfers()) {
+                if ((transfer->match(Transfer::StatusRole, filter)) && (transfer->match(Transfer::NameRole, query))) {
+                    matches++;
+
+                    if (matches > start) {
+                        list.append(transfer->itemDataWithRoleNames());
+
+                        foreach (Transfer *childTransfer, transfer->childTransfers()) {
+                            list.append(childTransfer->itemDataWithRoleNames());
+                        }
+                    }
+
+                    if (matches >= (start + count)) {
+                        break;
+                    }
+                }
+            }
+
+            return list;
+        }
+
+        foreach (Transfer *transfer, m_rootItem->childTransfers()) {
+            if (transfer->match(Transfer::StatusRole, filter)) {
+                matches++;
+
+                if (matches > start) {
+                    list.append(transfer->itemDataWithRoleNames());
+
+                    foreach (Transfer *childTransfer, transfer->childTransfers()) {
+                        list.append(childTransfer->itemDataWithRoleNames());
+                    }
+                }
+
+                if (matches >= (start + count)) {
+                    break;
+                }
+            }
+        }
+
+        return list;
+    };
+
+    for (int i = start; i < count; i++) {
+        list.append(m_rootItem->childTransfer(i)->itemDataWithRoleNames());
+
+        foreach (Transfer *childTransfer, m_rootItem->childTransfer(i)->childTransfers()) {
             list.append(childTransfer->itemDataWithRoleNames());
         }
     }
@@ -260,7 +358,7 @@ Transfer* TransferModel::get(const QString &id) const {
 
         foreach (Transfer *childTransfer, transfer->childTransfers()) {
             if (childTransfer->id() == id) {
-                return transfer;
+                return childTransfer;
             }
         }
     }
@@ -276,7 +374,7 @@ QModelIndexList TransferModel::match(const QModelIndex &start, int role, const Q
     if (!start.parent().isValid()) {
         int i = start.row();
 
-        while ((i < m_rootItem->childTransfers().size()) && ((hits == -1) || (matches.size() <= hits))) {
+        while ((i < m_rootItem->count()) && ((hits == -1) || (matches.size() <= hits))) {
             if (m_rootItem->childTransfer(i)->match(role, value)) {
                 matches.append(this->index(i, 0));
             }
@@ -296,6 +394,7 @@ void TransferModel::setSearchQuery(const QString &query) {
     if (query != this->searchQuery()) {
         m_searchQuery = query;
         this->filter();
+        emit searchQueryChanged(query);
     }
 }
 
@@ -307,15 +406,24 @@ void TransferModel::setStatusFilter(Transfers::Status status) {
     if (status != this->statusFilter()) {
         m_statusFilter = status;
         this->filter();
+        emit statusFilterChanged(status);
     }
 }
 
+void TransferModel::resetFilters() {
+    this->setSearchQuery(QString());
+    this->setStatusFilter(Transfers::Unknown);
+}
+
 Transfers::Action TransferModel::nextAction() const {
     return m_nextAction;
 }
 
 void TransferModel::setNextAction(Transfers::Action action) {
-    m_nextAction = action;
+    if (action != this->nextAction()) {
+        m_nextAction = action;
+        emit nextActionChanged(action);
+    }
 }
 
 void TransferModel::filter() {
@@ -641,10 +749,6 @@ void TransferModel::onTransferStatusChanged(Transfers::Status status) {
 
             emit countChanged(this->rowCount());
 
-            if (this->rowCount() == 0) {
-                QMetaObject::invokeMethod(Storage::instance(), "clearStoredTransfers", Qt::QueuedConnection);
-            }
-
             if (status == Transfers::Completed) {
                 switch (this->nextAction()) {
                 case Transfers::Pause:
@@ -661,6 +765,8 @@ void TransferModel::onTransferStatusChanged(Transfers::Status status) {
                     break;
                 }
             }
+
+            QMetaObject::invokeMethod(this, "storeTransfers", Qt::QueuedConnection);
         }
     }
     default:
@@ -682,30 +788,17 @@ void TransferModel::onMaximumConcurrentTransfersChanged(int oldMaximum, int newM
     }
     else if (newMaximum < oldMaximum) {
         if (newMaximum < m_activeTransfers.size()) {
-            int i = m_rootItem->count() - 1;
             int priority = Transfers::LowPriority;
 
             while (priority >= Transfers::HighPriority) {
-                while (i >= 0) {
-                    if (Transfer *transfer = m_rootItem->childTransfer(i)) {
-                        for (int ii = transfer->childTransfers().size() - 1; ii >= 0; ii--) {
-                            if ((transfer->childTransfer(ii)->priority() == priority) && (transfer->childTransfer(ii)->status() > Transfers::Queued)) {
-                                transfer->pause();
-                                return;
-                            }
-                        }
-
-                        if ((transfer->priority() == priority) && (transfer->status() > Transfers::Queued)) {
-                            transfer->pause();
-                            return;
-                        }
+                foreach (Transfer *transfer, m_activeTransfers) {
+                    if (transfer->priority() == priority) {
+                        transfer->pause();
+                        return;
                     }
-
-                    i--;
                 }
 
                 priority--;
-                i = m_rootItem->count() - 1;
             }
         }
     }
@@ -716,6 +809,7 @@ void TransferModel::storeTransfers() {
 }
 
 void TransferModel::storeAndDeleteTransfers() {
+    this->resetFilters(); // Ugly fix
     Storage::instance()->storeTransfers(m_rootItem->childTransfers(), true);
 }
 
