@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef TRANSFERMODEL_H
 #define TRANSFERMODEL_H
 
@@ -16,13 +33,16 @@ class TransferModel : public QAbstractItemModel
                NOTIFY countChanged)
     Q_PROPERTY(QString searchQuery
                READ searchQuery
-               WRITE setSearchQuery)
+               WRITE setSearchQuery
+               NOTIFY searchQueryChanged)
     Q_PROPERTY(Transfers::Status statusFilter
                READ statusFilter
-               WRITE setStatusFilter)
+               WRITE setStatusFilter
+               NOTIFY statusFilterChanged)
     Q_PROPERTY(Transfers::Action nextAction
                READ nextAction
-               WRITE setNextAction)
+               WRITE setNextAction
+               NOTIFY nextActionChanged)
     Q_PROPERTY(int totalDownloadSpeed
                READ totalDownloadSpeed
                NOTIFY totalDownloadSpeedChanged)
@@ -50,7 +70,7 @@ public:
     QMap<int, QVariant> itemData(const QModelIndex &index) const;
     Q_INVOKABLE QVariantMap itemData(int row, int parentRow) const;
     Q_INVOKABLE QVariantMap itemData(const QString &id) const;
-    Q_INVOKABLE QVariantList allItemData() const;
+    Q_INVOKABLE QVariantList allItemData(Transfers::Status filter = Transfers::Unknown, const QString &query = QString(), int start = 0, int count = -1) const;
 
     bool setData(const QModelIndex &index, const QVariant &value, int role);
     Q_INVOKABLE bool setData(int row, int parentRow, const QVariant &value, const QByteArray &role);
@@ -76,6 +96,7 @@ public:
 public slots:
     void setSearchQuery(const QString &query);
     void setStatusFilter(Transfers::Status status);
+    void resetFilters();
 
     void setNextAction(Transfers::Action action);
 
@@ -115,11 +136,14 @@ private slots:
 
 signals:
     void countChanged(int count);
+    void searchQueryChanged(const QString &query);
+    void statusFilterChanged(Transfers::Status status);
+    void nextActionChanged(Transfers::Action action);
     void totalDownloadSpeedChanged(int speed);
     void activeTransfersChanged(int active);
 
 private:
-    static TransferModel *m_instance;
+    static TransferModel *self;
 
     Transfer* m_rootItem;
     QTimer *m_queueTimer;
