@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "urlchecker.h"
 #include "utils.h"
 #include "pluginmanager.h"
@@ -8,7 +25,7 @@
 #include <QFile>
 #include <QIcon>
 
-UrlChecker* UrlChecker::m_instance = 0;
+UrlChecker* UrlChecker::self = 0;
 
 UrlChecker::UrlChecker() :
     QObject(),
@@ -16,8 +33,8 @@ UrlChecker::UrlChecker() :
     m_index(0),
     m_cancelled(false)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->connect(PluginManager::instance(), SIGNAL(pluginsReady()), this, SLOT(connectToPluginSignals()));
@@ -27,7 +44,7 @@ UrlChecker::UrlChecker() :
 UrlChecker::~UrlChecker() {}
 
 UrlChecker* UrlChecker::instance() {
-    return !m_instance ? new UrlChecker : m_instance;
+    return !self ? new UrlChecker : self;
 }
 
 UrlCheckModel* UrlChecker::model() {
@@ -110,10 +127,15 @@ void UrlChecker::checkFileDownload() {
 
 void UrlChecker::addUrlToQueue(const QUrl &url) {
     m_cancelled = false;
+
+    if (m_model->rowCount() == 0) {
+        m_index = 0;
+    }
+
     m_urlQueue.enqueue(url);
     m_model->addUrlCheck(url.toString());
 
-    if (!m_urlQueue.isEmpty()) {
+    if (m_urlQueue.size() == 1) {
         emit progressChanged(this->progress());
         this->checkUrl(m_urlQueue.dequeue());
     }
@@ -121,6 +143,11 @@ void UrlChecker::addUrlToQueue(const QUrl &url) {
 
 void UrlChecker::addUrlToQueue(const QString &url) {
     m_cancelled = false;
+
+    if (m_model->rowCount() == 0) {
+        m_index = 0;
+    }
+
 #if QT_VERSION >= 0x040600
     m_urlQueue.enqueue(QUrl::fromUserInput(url));
 #else
@@ -128,41 +155,25 @@ void UrlChecker::addUrlToQueue(const QString &url) {
 #endif
     m_model->addUrlCheck(url);
 
-    if (!m_urlQueue.isEmpty()) {
+    if (m_urlQueue.size() == 1) {
         emit progressChanged(this->progress());
         this->checkUrl(m_urlQueue.dequeue());
     }
 }
 
 void UrlChecker::addUrlsToQueue(QList<QUrl> urls) {
-    m_cancelled = false;
-
     foreach (QUrl url, urls) {
-        m_urlQueue.enqueue(url);
-        m_model->addUrlCheck(url.toString());
-    }
-
-    if (!m_urlQueue.isEmpty()) {
-        emit progressChanged(this->progress());
-        this->checkUrl(m_urlQueue.dequeue());
+        this->addUrlToQueue(url);
     }
 }
 
 void UrlChecker::addUrlsToQueue(QStringList urls) {
-    m_cancelled = false;
-
     foreach (QString url, urls) {
 #if QT_VERSION >= 0x040600
-        m_urlQueue.enqueue(QUrl::fromUserInput(url));
+        this->addUrlToQueue(QUrl::fromUserInput(url));
 #else
-        m_urlQueue.enqueue(url.startsWith("http") ? url : "http://" + url);
+        this->addUrlToQueue(url.startsWith("http") ? url : "http://" + url);
 #endif
-        m_model->addUrlCheck(url);
-    }
-
-    if (!m_urlQueue.isEmpty()) {
-        emit progressChanged(this->progress());
-        this->checkUrl(m_urlQueue.dequeue());
     }
 }
 
@@ -190,8 +201,6 @@ void UrlChecker::cancel() {
             m_urlQueue.clear();
         }
 
-        m_index = 0;
-
         emit cancelled();
     }
 }
@@ -209,9 +218,6 @@ void UrlChecker::onUrlChecked(bool ok, const QUrl &url, const QString &service,
         if ((!m_urlQueue.isEmpty()) && (!m_cancelled)) {
             this->checkUrl(m_urlQueue.dequeue());
         }
-        else {
-            m_index = 0;
-        }
     }
 }
 
@@ -333,6 +339,36 @@ bool UrlCheckModel::setData(const QModelIndex &index, const QVariant &value, int
     return true;
 }
 
+QMap<int, QVariant> UrlCheckModel::itemData(const QModelIndex &index) const {
+    QMap<int, QVariant> map;
+
+    for (int role = UrlRole; role <= OkRole; role++) {
+        map.insert(role, index.data(role));
+    }
+
+    return map;
+}
+
+QVariantMap UrlCheckModel::itemData(int row) const {
+    QVariantMap map;
+
+    for (int role = UrlRole; role <= OkRole; role++) {
+        map.insert(this->roleNames().value(role), this->index(row, 0).data(role));
+    }
+
+    return map;
+}
+
+QVariantList UrlCheckModel::allItemData() const {
+    QVariantList list;
+
+    for (int i = 0; i < this->rowCount(); i++) {
+        list.append(this->itemData(i));
+    }
+
+    return list;
+}
+
 void UrlCheckModel::addUrlCheck(const QString &url, bool checked, bool ok) {
     UrlCheck check;
     check.url = url;
