@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef URLCHECKER_H
 #define URLCHECKER_H
 
@@ -52,7 +69,7 @@ signals:
     void cancelled();
     
 private:
-    static UrlChecker *m_instance;
+    static UrlChecker *self;
 
     UrlCheckModel* m_model;
 
@@ -95,6 +112,9 @@ public:
 #if QT_VERSION >= 0x040600
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
 #endif
+    QMap<int, QVariant> itemData(const QModelIndex &index) const;
+    QVariantMap itemData(int row) const;
+    Q_INVOKABLE QVariantList allItemData() const;
 
 public slots:
     void clear();
