@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "urlretriever.h"
 #include "networkaccessmanager.h"
 #include "pluginmanager.h"
@@ -7,7 +24,7 @@
 #include <QFile>
 #include <QThread>
 
-UrlRetriever* UrlRetriever::m_instance = 0;
+UrlRetriever* UrlRetriever::self = 0;
 
 UrlRetriever::UrlRetriever() :
     QObject(),
@@ -17,8 +34,8 @@ UrlRetriever::UrlRetriever() :
     m_total(0),
     m_cancelled(false)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->connect(m_processor, SIGNAL(urlsProcessed(QList<QUrl>)), this, SLOT(onUrlsProcessed(QList<QUrl>)));
@@ -33,7 +50,7 @@ UrlRetriever::~UrlRetriever() {
 }
 
 UrlRetriever* UrlRetriever::instance() {
-    return !m_instance ? new UrlRetriever : m_instance;
+    return !self ? new UrlRetriever : self;
 }
 
 int UrlRetriever::progress() const {
@@ -46,6 +63,7 @@ void UrlRetriever::addUrlToQueue(const QUrl &url) {
     m_total = m_urlQueue.size();
 
     if (m_total == 1) {
+	m_index = 0;
         emit busy(tr("Retrieving URLs"), 100);
         emit progressChanged(0);
         this->getWebPage(m_urlQueue.dequeue());
@@ -58,6 +76,7 @@ void UrlRetriever::addUrlToQueue(const QString &url) {
     m_total = m_urlQueue.size();
 
     if (m_total == 1) {
+	m_index = 0;
         emit busy(tr("Retrieving URLs"), 100);
         emit progressChanged(0);
         this->getWebPage(m_urlQueue.dequeue());
@@ -65,34 +84,14 @@ void UrlRetriever::addUrlToQueue(const QString &url) {
 }
 
 void UrlRetriever::addUrlsToQueue(QList<QUrl> urls) {
-    m_cancelled = false;
-
     foreach (QUrl url, urls) {
-        m_urlQueue.enqueue(url);
-    }
-
-    m_total = m_urlQueue.size();
-
-    if (m_total == urls.size()) {
-        emit busy(tr("Retrieving URLs"), 100);
-        emit progressChanged(0);
-        this->getWebPage(m_urlQueue.dequeue());
+        this->addUrlToQueue(url);
     }
 }
 
 void UrlRetriever::addUrlsToQueue(QStringList urls) {
-    m_cancelled = false;
-
     foreach (QString url, urls) {
-        m_urlQueue.enqueue(url);
-    }
-
-    m_total = m_urlQueue.size();
-
-    if (m_total == urls.size()) {
-        emit busy(tr("Retrieving URLs"), 100);
-        emit progressChanged(0);
-        this->getWebPage(m_urlQueue.dequeue());
+        this->addUrlToQueue(url);
     }
 }
 
@@ -121,7 +120,6 @@ void UrlRetriever::cancel() {
         }
 
         m_urlQueue.clear();
-        m_index = 0;
 
         emit cancelled();
     }
@@ -186,8 +184,6 @@ void UrlRetriever::onUrlsProcessed(const QList<QUrl> &urls) {
     }
     else {
         emit finished();
-        m_index = 0;
-        m_total = 0;
     }
 }
 
