@@ -87,7 +87,7 @@ void BitShare::checkUrlIsValid() {
             emit urlChecked(false);
         }
         else {
-            QString fileName = response.section("<title>Download", 1, 1).section(" - BitShare.com", 0, 0);
+            QString fileName = response.section("<title>Download", 1, 1).section("- BitShare.com", 0, 0).trimmed();
 
             if (fileName.isEmpty()) {
                 emit urlChecked(false);
