@@ -29,6 +29,7 @@ public:
 
 private:
     void startWait(int msecs);
+    void constructDownloadUrl(const QString &url);
 
 private slots:
     void checkLogin();
@@ -43,6 +44,8 @@ signals:
 private:
     QTimer *m_waitTimer;
     int m_waitTime;
+    QString m_type;
+    QString m_fileName;
 };
 
 #endif // RAPIDSHARE_H
